pub struct RpcGetEndhostApisResponse {
pub groups: Vec<RpcEndhostApiGroup>,
}Expand description
Endhost APIs response message.
Fields
groups: Vec<RpcEndhostApiGroup>Set of Endhost APIs groups. Should be used in order, using the first reachable one.
After establishing a connection to an API in a group, the client can failover to any other API in the same group if the connection fails. Failover between groups requires the client to re-establish connections to snaps and other services using the new API.