EndhostApiDiscovery

Trait EndhostApiDiscovery 

pub trait EndhostApiDiscovery: Send + Sync {
    // Required method
    fn discover_endhost_apis<'life0, 'async_trait>(
        &'life0 self,
        public_ip: IpAddr,
    ) -> Pin<Box<dyn Future<Output = Vec<EndhostApiGroup>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             Self: 'async_trait;
}
Allows discovery of available Endhost APIs.

Required Methods

fn discover_endhost_apis<'life0, 'async_trait>( &'life0 self, public_ip: IpAddr, ) -> Pin<Box<dyn Future<Output = Vec<EndhostApiGroup>> + Send + 'async_trait>>
where 'life0: 'async_trait, Self: 'async_trait,

Discover available Endhost APIs

Returns a list of EndhostApiFailoverGroups representing the discovered Endhost APIs. This list is ordered by preference, with the most preferred API first.

Parameters
  • public_ip: The public IP address of the endhost making the discovery request.

Implementors