pub struct EndhostApiSourceError {
pub error: Error,
pub transient: bool,
}Expand description
Error type for failures to retrieve Endhost APIs from an EndhostApiSource.
Fields
error: ErrorThe underlying error that occurred while trying to retrieve the Endhost APIs
transient: boolIf true, the error is considered transient and the client may retry