Module path

Module path 

SCION stack path handling.

Modules

fetcher
A PathFetcher is responsible for providing paths between two ISD-ASes.
manager
Multipath manager for SCION path selection.
policy
Path policies allow for the selection of paths based on certain criteria.
scoring
Path scoring is the central component of path selection.
types
Path Manager specific types.

Structs

PathStrategy
PathStrategy combines multiple path operations into a single strategy.