A PathFetcher is responsible for providing paths between two ISD-ASes.
The default implementation PathFetcherImpl uses a SegmentFetcher to fetch path segments and combine them into end-to-end paths.
Modules
- traits
- Path fetcher traits and types.
Structs
- Endhost
ApiSegment Fetcher - Segment fetcher that uses the endhost API via Connect-RPC to fetch segments.
- Path
Fetcher Impl - Path fetcher.