CachingPathManager

Struct CachingPathManager 

pub struct CachingPathManager<F: PathFetcher = PathFetcherImpl> { /* private fields */ }
Active path manager that runs as a background task

Implementations

Source

impl<F: PathFetcher + Send + Sync + 'static> CachingPathManager<F>

pub fn start(path_strategy: PathStrategy, fetcher: F) -> Self

Create and start an active path manager with automatic task management. The background task is spawned internally and will be cancelled when the manager is dropped. This is the recommended method for most users.

pub fn start_future( selection: PathStrategy, fetcher: F, cancellation_token: CancellationToken, ) -> (Self, impl Future<Output = ()>)

Create the manager and task future.

pub fn try_cached_path( &self, src: IsdAsn, dst: IsdAsn, now: DateTime<Utc>, ) -> Result<Option<Path<Bytes>>>

Returns a cached path if it is not expired.