MultiPathManager

Struct MultiPathManager 

pub struct MultiPathManager<F: PathFetcher = PathFetcherImpl>(/* private fields */);
Path manager managing multiple paths per src-dst pair.

Implementations

Source

impl<F: PathFetcher> MultiPathManager<F>

pub fn new( config: MultiPathManagerConfig, fetcher: F, path_strategy: PathStrategy, ) -> Result<Self, &'static str>

Creates a new MultiPathManager.

pub fn try_path( &self, src: IsdAsn, dst: IsdAsn, now: SystemTime, ) -> Option<Path>

Tries to get the active path for the given src-dst pair.

If no active path is set, returns None.

If the src-dst pair is not yet managed, starts managing it.

pub async fn path( &self, src: IsdAsn, dst: IsdAsn, now: SystemTime, ) -> Result<Path, Arc<PathFetchError>>

Gets the active path for the given src-dst pair.

If the src-dst pair is not yet managed, starts managing it, possibly waiting for the first path fetch.

Returns an error if no path is available after waiting.

pub fn weak_ref(&self) -> MultiPathManagerRef<F>

Creates a weak reference to this MultiPathManager.

pub fn stop_managing_paths(&self, src: IsdAsn, dst: IsdAsn)

Stops managing paths for the given src-dst pair.

pub fn report_path_issue( &self, timestamp: SystemTime, issue: IssueKind, path: Option<&Path>, )

report error