pub struct MultiPathManagerConfig { /* private fields */ }Expand description
Configuration for the MultiPathManager.
Implementations
Sourceimpl MultiPathManagerConfig
impl MultiPathManagerConfig
Sourcepub fn with_max_cached_paths_per_pair(self, max: usize) -> Self
pub fn with_max_cached_paths_per_pair(self, max: usize) -> Self
Sets the maximum number of cached paths per src-dst pair.
Sourcepub fn with_refetch_interval(self, interval: Duration) -> Self
pub fn with_refetch_interval(self, interval: Duration) -> Self
Sets the interval between path refetches.
Sourcepub fn with_min_refetch_delay(self, delay: Duration) -> Self
pub fn with_min_refetch_delay(self, delay: Duration) -> Self
Sets the minimum duration between path refetches.
Sourcepub fn with_min_expiry_threshold(self, threshold: Duration) -> Self
pub fn with_min_expiry_threshold(self, threshold: Duration) -> Self
Sets the minimum remaining expiry before refetching paths.
Sourcepub fn with_max_idle_period(self, period: Duration) -> Self
pub fn with_max_idle_period(self, period: Duration) -> Self
Sets the maximum idle period before managed paths are removed.
Sourcepub fn with_issue_deduplication_window(self, window: Duration) -> Self
pub fn with_issue_deduplication_window(self, window: Duration) -> Self
Sets the time window during which duplicate issues are ignored.
Sourcepub fn with_path_swap_score_threshold(self, threshold: f32) -> Self
pub fn with_path_swap_score_threshold(self, threshold: f32) -> Self
Sets the score difference after which the active path should be replaced.