PathManager

Trait PathManager 

pub trait PathManager: SyncPathManager {
    // Required method
    fn path_wait(
        &self,
        src: IsdAsn,
        dst: IsdAsn,
        now: DateTime<Utc>,
    ) -> impl ResFut<'_, Path<Bytes>, PathWaitError>;
}
Trait for active path management with async interface.

Required Methods

fn path_wait( &self, src: IsdAsn, dst: IsdAsn, now: DateTime<Utc>, ) -> impl ResFut<'_, Path<Bytes>, PathWaitError>

Returns a path to the destination from the path cache or requests a new path from the SCION Control Plane.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<P: PathPolicy + Send + Sync + 'static, F: PathFetcher + Send + Sync + 'static> PathManager for CachingPathManager<P, F>