Path fetcher traits and types.
Enums
- Path
Wait Error - Errors returned when waiting for a path to a destination.
- Path
Wait Timeout Error - Errors returned when waiting for a path to a destination with a timeout.
Traits
- Path
Manager - Trait for active path management with async interface.
- Path
Prefetcher - Trait for prefetching paths in the path manager.
- Sync
Path Manager - Trait for active path management with sync interface. Implementors of this trait should be able to be used in sync and async context. The functions must not block.