#[non_exhaustive]pub enum PathWaitTimeoutError {
FetchFailed(Arc<PathFetchError>),
NoPathFound,
Timeout,
}Expand description
Errors returned when waiting for a path to a destination with a timeout.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FetchFailed(Arc<PathFetchError>)
Fetching a path from the configured segment sources failed.
The error is shared (Arc) because a single fetch failure may be reported to multiple
concurrent waiters.
NoPathFound
No path to the destination was found.
Timeout
Waiting for a path timed out.