Module policy

Module policy 

Path policies.

Structs

PolicyPath
A path wrapper that is passed to the path policy when selecting a path. In the future, this will be used to add additional information to the path.
Shortest
Selects the shortest path based on the number of hops.

Traits

PathPolicy
Path policy trait.