pub trait PathPolicy: 'static + Send + Sync { // Required method fn predicate(&self, path: &Path) -> bool; }
Path policies allow for the selection of paths based on certain criteria.
Returns true if the path should be considered for selection.