pub struct PathScorer { /* private fields */ }Expand description
Aggregates multiple path scorers into a single scoring function.
Implementations
Sourceimpl PathScorer
impl PathScorer
Sourcepub const DEFAULT_RELIABILITY_IMPACT: f32 = 1.0
pub const DEFAULT_RELIABILITY_IMPACT: f32 = 1.0
Default impact weight for reliability scorer.
Sourcepub const DEFAULT_LENGTH_IMPACT: f32 = 0.1
pub const DEFAULT_LENGTH_IMPACT: f32 = 0.1
Default impact weight for length scorer.
Sourcepub fn with_scorer(
self,
scorer: impl PathScoring + 'static,
impact: f32,
) -> Self
pub fn with_scorer( self, scorer: impl PathScoring + 'static, impact: f32, ) -> Self
Adds a scorer with the given impact weight.
scorer - The path scorer to add.
impact - The weight of the scorer in the final score aggregation.
e.g. Impact of 0.2 means the scorer can change the final score by up to ±0.2.
Note: The impact weight does not need to sum to 1.0 across all scorers.
Sourcepub fn score(&self, path: &PathManagerPath, now: SystemTime) -> f32
pub fn score(&self, path: &PathManagerPath, now: SystemTime) -> f32
Scores the given path by aggregating scores from all configured scorers.
Total score is the weighted sum of individual scorer scores. No Normalization is applied.
Sourcepub fn score_report(
&self,
path: &PathManagerPath,
now: SystemTime,
) -> ScoreReport
pub fn score_report( &self, path: &PathManagerPath, now: SystemTime, ) -> ScoreReport
Generates a report detailing individual scorer contributions to the total score of the path.