pub struct PathStrategy {
pub policies: Vec<Arc<dyn PathPolicy>>,
/* private fields */
}Expand description
PathStrategy combines multiple path operations into a single strategy.
Fields
policies: Vec<Arc<dyn PathPolicy>>The path policies to apply.
Implementations
Sourceimpl PathStrategy
impl PathStrategy
Sourcepub fn add_policy(&mut self, policy: impl PathPolicy)
pub fn add_policy(&mut self, policy: impl PathPolicy)
Appends a path policy to the list of policies.
Sourcepub fn predicate(&self, path: &ScionPath) -> bool
pub fn predicate(&self, path: &ScionPath) -> bool
Returns true if the given path is accepted by all policies.
If no policies are added, all paths are accepted.
Sourcepub fn filter_inplace(&self, paths: &mut Vec<ScionPath>)
pub fn filter_inplace(&self, paths: &mut Vec<ScionPath>)
Filters the given paths based on all policies, removing paths that are not accepted.