pub struct PathManagerPath {
pub path: Path,
pub from_registration: bool,
}Expand description
Path wrapper to allow additional metadata to be attached to a path for Ranking and Policies
Fields
path: PathThe actual SCION path
from_registration: boolIf the path was manually registered (true) or fetched (false)
Implementations
Sourceimpl PathManagerPath
impl PathManagerPath
Sourcepub fn is_from_registration(&self) -> bool
pub fn is_from_registration(&self) -> bool
Returns true if this path came from registration rather than fetching
Sourcepub fn scion_path(&self) -> &Path
pub fn scion_path(&self) -> &Path
Get the underlying scion path