pub enum BuildScionStackError {
UnderlayUnavailable(Cow<'static, str>),
UnderlayDiscoveryError(CrpcClientError),
EndhostApiClientSetupError(Error),
Snap(BuildSnapScionStackError),
Udp(BuildUdpScionStackError),
Internal(Error),
}Expand description
Build SCION stack errors.
Variants
Discovery returned no underlay or no underlay was provided.
UnderlayDiscoveryError(CrpcClientError)
Error making the underlay discovery request to the endhost API. E.g. because the endhost API is not reachable. This error is only returned if the underlay is not statically configured.
EndhostApiClientSetupError(Error)
Error setting up the endhost API client.
Snap(BuildSnapScionStackError)
Error building the SNAP SCION stack. This error is only returned if a SNAP underlay is used.
Udp(BuildUdpScionStackError)
Error building the UDP SCION stack. This error is only returned if a UDP underlay is used.
Internal(Error)
Internal error, this should never happen.