pub struct SnapUnderlayConfigBuilder(/* private fields */);Expand description
SNAP underlay configuration builder.
Implementations
Sourceimpl SnapUnderlayConfigBuilder
impl SnapUnderlayConfigBuilder
Sourcepub fn with_auth_token(self, token: String) -> Self
pub fn with_auth_token(self, token: String) -> Self
Set a static token to use for authentication with the SNAP control plane.
Sourcepub fn with_auth_token_source(self, source: impl TokenSource) -> Self
pub fn with_auth_token_source(self, source: impl TokenSource) -> Self
Set a token source to use for authentication with the SNAP control plane.
Sourcepub fn with_snap_dp_index(self, dp_index: usize) -> Self
pub fn with_snap_dp_index(self, dp_index: usize) -> Self
Set the index of the SNAP data plane to use.
Arguments
dp_index- The index of the SNAP data plane to use.
Sourcepub fn with_tunnel_reconnect_backoff(
self,
minimum_delay_secs: Duration,
maximum_delay_secs: Duration,
factor: f32,
jitter_secs: Duration,
) -> Self
pub fn with_tunnel_reconnect_backoff( self, minimum_delay_secs: Duration, maximum_delay_secs: Duration, factor: f32, jitter_secs: Duration, ) -> Self
Set the parameters for the exponential backoff configuration for reconnecting a SNAP tunnel.
Arguments
minimum_delay_secs- The minimum delay in seconds.maximum_delay_secs- The maximum delay in seconds.factor- The factor to multiply the delay by.jitter_secs- The jitter in seconds.
Sourcepub fn build(self) -> SnapUnderlayConfig
pub fn build(self) -> SnapUnderlayConfig