pub enum InvalidBindAddressError {
ServiceAddress(SocketAddr),
CannotBindToRequestedAddress(SocketAddr, Cow<'static, str>),
AddressMismatch {
assigned_addr: SocketAddr,
bind_addr: SocketAddr,
},
NoLocalIpAddressFound,
}Expand description
Error related to the bind address of the socket.
Variants
ServiceAddress(SocketAddr)
The provided bind address is a service address.
CannotBindToRequestedAddress(SocketAddr, Cow<'static, str>)
The requested bind address cannot be bound to.
AddressMismatch
The assigned address does not match the requested address. This is likely due to NAT.
Fields

assigned_addr: SocketAddrThe assigned address.

bind_addr: SocketAddrThe requested bind address.
NoLocalIpAddressFound
Could not find any local IP address to bind to.