pub enum ScionSocketBindError {
InvalidBindAddress(InvalidBindAddressError),
PortAlreadyInUse(u16),
SnapConnectionError(SnapConnectionError),
NoUnderlayAvailable(Isd),
Other(Box<dyn Error + Send + Sync>),
}Expand description
Error return when binding a socket.
Variants
InvalidBindAddress(InvalidBindAddressError)
The provided bind address cannot be bound to. E.g. because it is not assigned to the endhost or because the address type is not supported.
PortAlreadyInUse(u16)
The provided port is already in use.
SnapConnectionError(SnapConnectionError)
Failed to connect to SNAP data plane.
NoUnderlayAvailable(Isd)
No underlay available to bind the requested address.
Other(Box<dyn Error + Send + Sync>)
An error that is not covered by the variants above.