pub enum ScionSocketSendError {
PathLookupError(Cow<'static, str>),
NetworkUnreachable(NetworkError),
InvalidPacket(Cow<'static, str>),
Closed,
IoError(Error),
NotConnected,
}Expand description
SCION socket send errors.
Variants
PathLookupError(Cow<'static, str>)
There was an error looking up the path in the path registry.
NetworkUnreachable(NetworkError)
The desination is not reachable. E.g. because no path is available.
InvalidPacket(Cow<'static, str>)
The provided packet is invalid. The underlying socket is not able to process the packet.
Closed
The underlying socket is closed.
IoError(Error)
IO Error from the underlying connection.
NotConnected
Error return when send is called on a socket that is not connected.