pub struct PathUnawareUdpScionSocket { /* private fields */ }Expand description
A path unaware UDP SCION socket.
Implementations
Sourceimpl PathUnawareUdpScionSocket
impl PathUnawareUdpScionSocket
Sourcepub fn send_to_via<'a>(
&'a self,
payload: &[u8],
destination: SocketAddr,
path: &Path<&[u8]>,
) -> BoxFuture<'a, Result<(), ScionSocketSendError>>
pub fn send_to_via<'a>( &'a self, payload: &[u8], destination: SocketAddr, path: &Path<&[u8]>, ) -> BoxFuture<'a, Result<(), ScionSocketSendError>>
Send a SCION UDP datagram via the given path.
Cancel safety
This method is cancel-safe. If the future is dropped before completion, the packet may be silently lost, but no socket state is corrupted and the socket remains usable.
Sourcepub fn recv_from_with_path<'a>(
&'a self,
buffer: &'a mut [u8],
path_buffer: &'a mut [u8],
) -> BoxFuture<'a, Result<(usize, SocketAddr, Path<&'a mut [u8]>), ScionSocketReceiveError>>
pub fn recv_from_with_path<'a>( &'a self, buffer: &'a mut [u8], path_buffer: &'a mut [u8], ) -> BoxFuture<'a, Result<(usize, SocketAddr, Path<&'a mut [u8]>), ScionSocketReceiveError>>
Receive a SCION packet with the sender and path.
Cancel safety
This method is cancel-safe. The only await point is the inner underlay receive. If the
future is dropped while waiting for a packet, no packet data is consumed and buffer
and path_buffer are left unmodified. If a packet has already been received (i.e., the
future is dropped after data has been written into the buffers), this cannot occur in
practice because those steps run synchronously within a single poll invocation.
Sourcepub fn recv_from<'a>(
&'a self,
buffer: &'a mut [u8],
) -> BoxFuture<'a, Result<(usize, SocketAddr), ScionSocketReceiveError>>
pub fn recv_from<'a>( &'a self, buffer: &'a mut [u8], ) -> BoxFuture<'a, Result<(usize, SocketAddr), ScionSocketReceiveError>>
Receive a SCION packet with the sender.
Cancel safety
This method is cancel-safe. If the future is dropped while waiting for a packet, no
packet is consumed and buffer is left unmodified. The contents of buffer are only
valid after the method returns Ok.