SocketConfig

Struct SocketConfig 

pub struct SocketConfig { /* private fields */ }
Configuration for a path aware socket.

Implementations

Source

impl SocketConfig

pub fn new() -> Self

Creates a new default socket configuration.

pub fn with_path_policy(self, policy: impl PathPolicy) -> Self

Adds a path policy.

Path policies can restrict the set of usable paths based on their characteristics. E.g. filtering out paths that go through certain ASes.

See HopPatternPolicy and AclPolicy

pub fn with_path_scoring(self, scoring: impl PathScoring, impact: f32) -> Self

Add a path scoring strategy.

Path scores signal which paths to prioritize based on their characteristics.

scoring - The path scoring strategy to add. impact - The impact weight of the scoring strategy. Higher values increase the influence

If no scoring strategies are added, scoring defaults to preferring shorter and more reliable paths.

pub fn with_connection_timeout(self, timeout: Duration) -> Self

Sets connection timeout for connect functions

Defaults to DEFAULT_CONNECT_TIMEOUT

pub fn with_segment_fetcher(self, fetcher: Box<dyn SegmentFetcher>) -> Self

Add an additional segment fetcher.

By default, only path segments retrieved via the endhost API are used. Adding additional segment fetchers enables to build paths from different segment sources.

pub fn disable_endhost_api_segment_fetcher(self) -> Self

Disable fetching path segments from the endhost API.