UdpScionSocket

Struct UdpScionSocket 

pub struct UdpScionSocket<P: PathManager = CachingPathManager> { /* private fields */ }
A path aware UDP socket generic over the underlay socket and path manager.

Implementations

Source

impl<P: PathManager> UdpScionSocket<P>

pub fn new( socket: PathUnawareUdpScionSocket, pather: Arc<P>, remote_addr: Option<SocketAddr>, ) -> Self

Creates a new path aware UDP SCION socket.

pub fn connect(self, remote_addr: SocketAddr) -> Self

Connects the socket to a remote address.

pub async fn send(&self, payload: &[u8]) -> Result<(), ScionSocketSendError>

Send a datagram to the connected remote address.

pub async fn send_to( &self, payload: &[u8], destination: SocketAddr, ) -> Result<(), ScionSocketSendError>

Send a datagram to the specified destination.

pub async fn send_to_via( &self, payload: &[u8], destination: SocketAddr, path: &Path<&[u8]>, ) -> Result<(), ScionSocketSendError>

Send a datagram to the specified destination via the specified path.

pub async fn recv_from_with_path<'a>( &'a self, buffer: &'a mut [u8], path_buffer: &'a mut [u8], ) -> Result<(usize, SocketAddr, Path<&'a mut [u8]>), ScionSocketReceiveError>

Receive a datagram from any address, along with the sender address and path.

pub async fn recv_from( &self, buffer: &mut [u8], ) -> Result<(usize, SocketAddr), ScionSocketReceiveError>

Receive a datagram from the connected remote address and write it into the provided buffer.

pub async fn recv( &self, buffer: &mut [u8], ) -> Result<usize, ScionSocketReceiveError>

Receive a datagram from the connected remote address.

Datagrams from other addresses are silently discarded.

pub fn local_addr(&self) -> SocketAddr

Returns the local socket address.