ScionStackBuilder

Struct ScionStackBuilder 

pub struct ScionStackBuilder { /* private fields */ }
Builder for creating a ScionStack.

Example

use scion_stack::stack::builder::ScionStackBuilder;
use url::Url;

async fn setup_scion_stack() {
    let control_plane_url: Url = "http://127.0.0.1:1234".parse().unwrap();

    let scion_stack = ScionStackBuilder::new()
        .with_endhost_api(control_plane_url)
        .with_auth_token("snap_token".to_string())
        .build()
        .await
        .unwrap();
}

Implementations

Source

impl ScionStackBuilder

pub fn new() -> Self

Create a new ScionStackBuilder.

The stack uses the the endhost API to discover the available data planes. By default, udp dataplanes are preferred over snap dataplanes.

pub fn with_preferred_underlay(self, preferred: PreferredUnderlay) -> Self

Sets which underlay to prefer when discovering data planes, if both are available.

Defaults to PreferredUnderlay::Udp.

pub fn with_crpc_client(self, crpc_client: Client) -> Self

Set a custom CRPC client for discovering and connecting to data planes.

Can be useful if no DNS resolution is possible, so the client can be configured with custom name resolution or with IP addresses directly.

pub fn with_endhost_api(self, endhost_api_url: Url) -> Self

Set a static endhost API

Replaces existing endhost API source.

See Self::with_endhost_api_discovery_source for more flexible configuration

pub fn with_endhost_api_discovery_source( self, source: impl EndhostApiSource, ) -> Self

Sets how the client will find its endhost APIs.

If none is set, the stack will fall back to using the global discovery API.

pub fn with_endhost_api_auth_token_source( self, source: impl TokenSource, ) -> Self

Set a token source to use for authentication with the endhost API.

pub fn with_endhost_api_auth_token(self, token: String) -> Self

Set a static token to use for authentication with the endhost API.

pub fn with_auth_token_source(self, source: impl TokenSource) -> Self

Set a token source to use for authentication both with the endhost API and the SNAP control plane. If a more specific token source is set, it takes precedence over this token source.

pub fn with_auth_token(self, token: String) -> Self

Set a static token to use for authentication both with the endhost API and the SNAP control plane. If a more specific token is set, it takes precedence over this token.

pub fn with_endhost_api_discovery_max_groups(self, max_groups: usize) -> Self

Set the maximum number of API groups to probe during endhost API discovery.

Groups are ordered by priority; only the first max_groups non-empty groups returned by the discovery source are considered. Defaults to 5.

pub fn with_anapaya_ead_apis_per_group(self, apis_per_group: usize) -> Self

Set the maximum number of APIs to probe per group during endhost API discovery.

APIs are selected at random within each group. Setting this to a higher value increases redundancy at the cost of additional concurrent connections. Defaults to 2.

pub fn with_endhost_api_discovery_per_group_delay( self, per_group_delay: Duration, ) -> Self

Set the delay before APIs in group k begin connecting, measured from the start of discovery.

Group k starts after k × per_group_delay or as soon as group k-1 is fully exhausted, whichever comes first. A shorter delay reduces time-to-connect when a high-priority group is slow, at the cost of additional concurrent connections to lower-priority groups. Defaults to 500 ms.

pub fn with_snap_underlay_config(self, config: SnapUnderlayConfig) -> Self

Set SNAP underlay specific configuration for the SCION stack.

pub fn with_udp_underlay_config(self, config: UdpUnderlayConfig) -> Self

Set UDP underlay specific configuration for the SCION stack.

pub async fn build(self) -> Result<ScionStack, BuildScionStackError>

Build the SCION stack.

Returns

A new SCION stack.