pub struct SnapUnderlayConfig { /* private fields */ }Expand description
SNAP underlay configuration.
Construct with SnapUnderlayConfig::default and customize with the consuming with_*
methods, then pass to ScionStackBuilder::with_snap_underlay_config.
Implementations
Sourceimpl SnapUnderlayConfig
impl SnapUnderlayConfig
Sourcepub fn with_auth_token(self, token: String) -> Self
pub fn with_auth_token(self, token: String) -> Self
Sets a static token to use for authentication with the SNAP control plane.
Sourcepub fn with_auth_token_source(self, source: impl TokenSource) -> Self
pub fn with_auth_token_source(self, source: impl TokenSource) -> Self
Sets a token source to use for authentication with the SNAP control plane.
Sourcepub fn with_crpc_client(self, client: Client) -> Self
pub fn with_crpc_client(self, client: Client) -> Self
Sets a custom CRPC client for discovering and connecting to data planes.
Sourcepub fn with_snap_dp_index(self, dp_index: usize) -> Self
pub fn with_snap_dp_index(self, dp_index: usize) -> Self
Sets the index of the SNAP data plane to use.
Sourcepub fn with_static_identity(self, identity: StaticSecret) -> Self
pub fn with_static_identity(self, identity: StaticSecret) -> Self
Sets the static identity to use for snap-tun connections.
If unset, a random static identity is generated.