pub struct ScmpScionSocket { /* private fields */ }Expand description
A SCMP SCION socket.
Implementations
Sourceimpl ScmpScionSocket
impl ScmpScionSocket
Sourcepub async fn send_to_via(
&self,
message: ScmpMessage,
destination: ScionAddr,
path: &ScionPath,
) -> Result<(), ScionSocketSendError>
pub async fn send_to_via( &self, message: ScmpMessage, destination: ScionAddr, path: &ScionPath, ) -> Result<(), ScionSocketSendError>
Send a SCMP message to the destination via the given path.
Sourcepub async fn recv_from_with_path(
&self,
) -> Result<(Box<ScmpPayloadView>, ScionAddr, ScionPath), ScionSocketReceiveError>
pub async fn recv_from_with_path( &self, ) -> Result<(Box<ScmpPayloadView>, ScionAddr, ScionPath), ScionSocketReceiveError>
Receive a SCMP message with the sender and path.
Sourcepub async fn recv_from(
&self,
) -> Result<(Box<ScmpPayloadView>, ScionAddr), ScionSocketReceiveError>
pub async fn recv_from( &self, ) -> Result<(Box<ScmpPayloadView>, ScionAddr), ScionSocketReceiveError>
Receive a SCMP message with the sender.
Sourcepub fn local_addr(&self) -> ScionSocketIpAddr
pub fn local_addr(&self) -> ScionSocketIpAddr
Return the local socket address.
Sourcepub fn snap_data_plane(&self) -> Option<SocketAddr>
pub fn snap_data_plane(&self) -> Option<SocketAddr>
The SNAP data plane the socket is connected to (if SNAP underlay is used).