pub struct TargetAddrOutboundIpResolver { /* private fields */ }Expand description
An outbound IP resolver that resolves the local IP address that can be used to reach a target API address.
DNS overrides in host_overrides take precedence over the OS resolver. This allows
the resolver to be used in environments where the OS resolver is not aware of custom
hostname-to-IP mappings (e.g. when ConnectParameters::hosts is set).
Implementations
Sourceimpl TargetAddrOutboundIpResolver
impl TargetAddrOutboundIpResolver
Sourcepub fn new(url: Url, host_overrides: Vec<(String, IpAddr)>) -> Self
pub fn new(url: Url, host_overrides: Vec<(String, IpAddr)>) -> Self
Create an outbound IP resolver for the given target url with a set of hostname-to-IP
overrides.
When resolving the outbound IP towards url, entries in host_overrides are checked before
the OS resolver. Pass an empty vec when no overrides are needed.