Endhost API Source.
This module defines the EndhostApiSource trait, which is responsible for discovering and
providing access to the Endhost API. Implementations of this trait can be used to discover the
API in different environments, such as through environment variables, configuration files, or
network discovery.
Modules
- models
- Re-exports of Endhost API discovery models from
endhost_api_discovery_models
Structs
- Endhost
ApiSource Error - Error type for failures to retrieve Endhost APIs from an
EndhostApiSource. - Static
Endhost ApiDiscovery - A static list of Endhost API discovery services which the stack can use to discover Endhost APIs.
- Static
Endhost Apis - A static list of Endhost APIs which the stack can use.
Traits
- Endhost
ApiSource - Returns available Endhost APIs for the client to use