pub struct StaticEndhostApis { /* private fields */ }Expand description
A static list of Endhost APIs which the stack can use.
Implementations
Sourceimpl StaticEndhostApis
impl StaticEndhostApis
Sourcepub fn add_group(self, group: Vec<Url>) -> Self
pub fn add_group(self, group: Vec<Url>) -> Self
Adds a group of Endhost APIs to the list of available APIs.
Endhost APIs in one group must offer the same data when queried. Meaning they should know the same set of underlays and segments.
The client can freely failover between APIs in the same group.
Endhost APIs in different groups can differ in the data they offer, however the client must close all open connections to failover between groups.