Module path

Module path 

SCION stack path handling.

Modules

manager
Path manager
policy
Path policies allow for the selection of paths based on certain criteria.
ranking
Path ranking allows expressing preferences between paths.
types
Path Manager specific types.

Structs

PathStrategy
PathStrategy combines multiple path operations into a single strategy.