A PathFetcher is responsible for providing paths between two ISD-ASes.
The default implementation PathFetcherImpl uses a SegmentFetcher to fetch path segments and combine them into end-to-end paths.
The default SegmentFetcher implementation is ConnectRpcSegmentFetcher, requesting segments from the Endhost API.
Modules
- traits
- Path fetcher traits and types.
Structs
- Connect
RpcSegment Fetcher - Connect RPC segment fetcher.
- Path
Fetcher Impl - Path fetcher.