pub struct ReliabilityScore { /* private fields */ }Expand description
Reliability score for a path
A reliability score indicates how reliable a path is, based on reported issues. The score decays over time, allowing paths to recover over time if no further issues are reported.
Implementations
Sourceimpl ReliabilityScore
impl ReliabilityScore
Sourcepub fn score(&self, now: SystemTime) -> Score
pub fn score(&self, now: SystemTime) -> Score
Returns the current reliability score, decayed to now.
Sourcepub fn new_with_time(now: SystemTime) -> Self
pub fn new_with_time(now: SystemTime) -> Self
Creates a new ReliabilityScore with initial score of 0.0
now is the current time for initialization, used for decay calculations.
Sourcepub fn update(&mut self, penalty: Score, now: SystemTime)
pub fn update(&mut self, penalty: Score, now: SystemTime)
Updates the reliability score based on the reported issue.
penalty is the penalty score to apply usually a negative value.
now is the current time for decay calculations.