pub struct CachingPathManager<F: PathFetcher = PathFetcherImpl> { /* private fields */ }Expand description
Active path manager that runs as a background task
Implementations
Sourceimpl<F: PathFetcher + Send + Sync + 'static> CachingPathManager<F>
impl<F: PathFetcher + Send + Sync + 'static> CachingPathManager<F>
Sourcepub fn start(path_strategy: PathStrategy, fetcher: F) -> Self
pub fn start(path_strategy: PathStrategy, fetcher: F) -> Self
Create and start an active path manager with automatic task management. The background task is spawned internally and will be cancelled when the manager is dropped. This is the recommended method for most users.
Sourcepub fn start_future(
selection: PathStrategy,
fetcher: F,
cancellation_token: CancellationToken,
) -> (Self, impl Future<Output = ()>)
pub fn start_future( selection: PathStrategy, fetcher: F, cancellation_token: CancellationToken, ) -> (Self, impl Future<Output = ()>)
Create the manager and task future.