pub struct MultiPathManager<F: PathFetcher = PathFetcherImpl>(/* private fields */);Expand description
Path manager managing multiple paths per src-dst pair.
Implementations
Sourceimpl<F: PathFetcher> MultiPathManager<F>
impl<F: PathFetcher> MultiPathManager<F>
Sourcepub fn new(
config: MultiPathManagerConfig,
fetcher: F,
path_strategy: PathStrategy,
) -> Result<Self, &'static str>
pub fn new( config: MultiPathManagerConfig, fetcher: F, path_strategy: PathStrategy, ) -> Result<Self, &'static str>
Creates a new MultiPathManager.
Sourcepub fn try_path(
&self,
src: IsdAsn,
dst: IsdAsn,
now: SystemTime,
) -> Option<Path>
pub fn try_path( &self, src: IsdAsn, dst: IsdAsn, now: SystemTime, ) -> Option<Path>
Tries to get the active path for the given src-dst pair.
If no active path is set, returns None.
If the src-dst pair is not yet managed, starts managing it.
Sourcepub async fn path(
&self,
src: IsdAsn,
dst: IsdAsn,
now: SystemTime,
) -> Result<Path, Arc<PathFetchError>>
pub async fn path( &self, src: IsdAsn, dst: IsdAsn, now: SystemTime, ) -> Result<Path, Arc<PathFetchError>>
Gets the active path for the given src-dst pair.
If the src-dst pair is not yet managed, starts managing it, possibly waiting for the first path fetch.
Returns an error if no path is available after waiting.
Sourcepub fn weak_ref(&self) -> MultiPathManagerRef<F>
pub fn weak_ref(&self) -> MultiPathManagerRef<F>
Creates a weak reference to this MultiPathManager.
Sourcepub fn stop_managing_paths(&self, src: IsdAsn, dst: IsdAsn)
pub fn stop_managing_paths(&self, src: IsdAsn, dst: IsdAsn)
Stops managing paths for the given src-dst pair.
Sourcepub fn report_path_issue(
&self,
timestamp: SystemTime,
issue: IssueKind,
path: Option<&Path>,
)
pub fn report_path_issue( &self, timestamp: SystemTime, issue: IssueKind, path: Option<&Path>, )
report error