PathPolicy

Trait PathPolicy 

pub trait PathPolicy:
    'static
    + Send
    + Sync {
    // Required method
    fn predicate(&self, path: &PathManagerPath) -> bool;
}
Path policies allow for the selection of paths based on certain criteria.

Required Methods

fn predicate(&self, path: &PathManagerPath) -> bool

Returns true if the path should be considered for selection.

Implementors