pub trait PathPolicy:
'static
+ Send
+ Sync {
// Required method
fn predicate(&self, path: &PathManagerPath) -> bool;
}Expand description
Path policies allow for the selection of paths based on certain criteria.
Required Methods
Sourcefn predicate(&self, path: &PathManagerPath) -> bool
fn predicate(&self, path: &PathManagerPath) -> bool
Returns true if the path should be considered for selection.