PathPolicy

Trait PathPolicy 

pub trait PathPolicy {
    // Required methods
    fn predicate(&self, path: &PolicyPath<'_>) -> bool;
    fn rank(&self, path1: &PolicyPath<'_>, path2: &PolicyPath<'_>) -> Ordering;
}
Path policy trait.

Required Methods

fn predicate(&self, path: &PolicyPath<'_>) -> bool

Returns true if the path should be considered for selection.

fn rank(&self, path1: &PolicyPath<'_>, path2: &PolicyPath<'_>) -> Ordering

Indicates which of two paths is preferred, greater values are preferred.

Implementors