pub struct PathStrategy {
pub policies: Vec<Arc<dyn PathPolicy>>,
pub scoring: PathScorer,
}Expand description
PathStrategy combines multiple path operations into a single strategy.
Fields
policies: Vec<Arc<dyn PathPolicy>>The path policies to apply.
scoring: PathScorerThe path ranking functions to apply.
Implementations
Sourceimpl PathStrategy
impl PathStrategy
Sourcepub fn add_policy(&mut self, policy: impl PathPolicy)
pub fn add_policy(&mut self, policy: impl PathPolicy)
Appends a path policy to the list of policies.
Sourcepub fn add_scoring(&mut self, scoring: impl PathScoring, impact: f32)
pub fn add_scoring(&mut self, scoring: impl PathScoring, impact: f32)
Adds a path scorer with the given impact weight.
Scores from paths are used to select the best path among multiple candidates.
scorer - The path scorer to add.
impact - The weight of the scorer in the final score aggregation.
e.g. Impact of 0.2 means the scorer can change the final score by up to ±0.2.
Note: The impact weight does not need to sum to 1.0 across all scorers.
Sourcepub fn rank_order(
&self,
this: &PathManagerPath,
other: &PathManagerPath,
now: SystemTime,
) -> Ordering
pub fn rank_order( &self, this: &PathManagerPath, other: &PathManagerPath, now: SystemTime, ) -> Ordering
Ranks the order of two paths based on preference.
Return
Returns the preference ordering between two paths.
Ordering::Lessifthisis preferred overotherOrdering::Greaterifotheris preferred overthisOrdering::Equalif both paths are equally preferred
Sourcepub fn rank_inplace(&self, path: &mut [PathManagerPath], now: SystemTime)
pub fn rank_inplace(&self, path: &mut [PathManagerPath], now: SystemTime)
Sorts the given paths in place, placing the most preferred paths first.
If no ranking functions are added, the paths are not modified.
Sourcepub fn predicate(&self, path: &Path) -> bool
pub fn predicate(&self, path: &Path) -> bool
Returns true if the given path is accepted by all policies.
If no policies are added, all paths are accepted.
Sourcepub fn filter_inplace<'path: 'iter, 'iter>(&self, paths: &mut Vec<Path>)
pub fn filter_inplace<'path: 'iter, 'iter>(&self, paths: &mut Vec<Path>)
Filters the given paths based on all policies, removing paths that are not accepted.