ScionStackBuilder

Struct ScionStackBuilder 

pub struct ScionStackBuilder { /* private fields */ }
Builder for creating a ScionStack.

Example

use scion_stack::scionstack::builder::ScionStackBuilder;
use url::Url;

async fn setup_scion_stack() {
    let control_plane_url: Url = "http://127.0.0.1:1234".parse().unwrap();

    let scion_stack = ScionStackBuilder::new(control_plane_url)
        .with_auth_token("snap_token".to_string())
        .build()
        .await
        .unwrap();
}

Implementations

Source

impl ScionStackBuilder

pub fn new(endhost_api_url: Url) -> Self

Create a new ScionStackBuilder.

The stack uses the the endhost API to discover the available data planes. By default, udp dataplanes are preferred over snap dataplanes.

pub fn with_prefer_snap(self) -> Self

When discovering data planes, prefer SNAP data planes if available.

pub fn with_prefer_udp(self) -> Self

When discovering data planes, prefer UDP data planes if available.

pub fn with_endhost_api_auth_token_source( self, source: impl TokenSource, ) -> Self

Set a token source to use for authentication with the endhost API.

pub fn with_endhost_api_auth_token(self, token: String) -> Self

Set a static token to use for authentication with the endhost API.

pub fn with_auth_token_source(self, source: impl TokenSource) -> Self

Set a token source to use for authentication both with the endhost API and the SNAP control plane. If a more specific token source is set, it takes precedence over this token source.

pub fn with_auth_token(self, token: String) -> Self

Set a static token to use for authentication both with the endhost API and the SNAP control plane. If a more specific token is set, it takes precedence over this token.

pub fn with_snap_underlay_config(self, config: SnapUnderlayConfig) -> Self

Set SNAP underlay specific configuration for the SCION stack.

pub fn with_udp_underlay_config(self, config: UdpUnderlayConfig) -> Self

Set UDP underlay specific configuration for the SCION stack.

pub async fn build(self) -> Result<ScionStack, BuildScionStackError>

Build the SCION stack.

Returns

A new SCION stack.