SnapUnderlayConfigBuilder

Struct SnapUnderlayConfigBuilder 

pub struct SnapUnderlayConfigBuilder(/* private fields */);
SNAP underlay configuration builder.

Implementations

Source

impl SnapUnderlayConfigBuilder

pub fn with_auth_token(self, token: String) -> Self

Set a static token to use for authentication with the SNAP control plane.

pub fn with_auth_token_source(self, source: impl TokenSource) -> Self

Set a token source to use for authentication with the SNAP control plane.

pub fn with_requested_addresses( self, requested_addresses: Vec<EndhostAddr>, ) -> Self

Set the addresses to request from the SNAP server. Note, that the server may choose not to assign all requested addresses and may assign additional addresses. Use assigned_addresses() to get the final list of addresses.

Arguments
  • requested_addresses - The addresses to request from the SNAP server.
pub fn with_ports_rng(self, rng: ChaCha8Rng) -> Self

Set the random number generator used for port allocation.

Arguments
  • rng - The random number generator.
pub fn with_ports_reserved_time(self, reserved_time: Duration) -> Self

Set how long ports are reserved after they are released.

Arguments
  • reserved_time - The reserved time for ports.
pub fn with_default_scmp_handler( self, default_scmp_handler: Box<dyn FnOnce(Arc<SnapTunnel>) -> Arc<dyn ScmpHandler> + Sync + Send + 'static>, ) -> Self

Set the default SCMP handler.

Arguments
  • default_scmp_handler - The default SCMP handler.
pub fn with_session_auto_renewal(self, interval: Duration) -> Self

Set the automatic session renewal.

Arguments
  • session_auto_renewal - The automatic session renewal.
pub fn with_snap_dp_index(self, dp_index: usize) -> Self

Set the index of the SNAP data plane to use.

Arguments
  • dp_index - The index of the SNAP data plane to use.
pub fn build(self) -> SnapUnderlayConfig

Build the SNAP stack configuration.

Returns

A new SNAP stack configuration.