pub enum ScionSocketBindError {
InvalidBindAddress(SocketAddr, String),
PortAlreadyInUse(u16),
Other(Box<dyn Error + Send + Sync>),
Internal(String),
}Expand description
Error return when binding a socket.
Variants
InvalidBindAddress(SocketAddr, String)
The provided bind address cannot be bount to. E.g. because it is not assigned to the endhost or because the address type is not supported.
PortAlreadyInUse(u16)
The provided port is already in use.
Other(Box<dyn Error + Send + Sync>)
An error that is not covered by the variants above.
Internal(String)
Internal error.