pub struct SocketConfig { /* private fields */ }Expand description
Configuration for a path aware socket.
Implementations
Sourceimpl SocketConfig
impl SocketConfig
Sourcepub fn with_path_policy(self, policy: impl PathPolicy) -> Self
pub fn with_path_policy(self, policy: impl PathPolicy) -> Self
Adds a path policy.
Path policies can restrict the set of usable paths based on their characteristics. E.g. filtering out paths that go through certain ASes.
See HopPatternPolicy and
AclPolicy
Sourcepub fn with_path_ranking(self, ranking: impl PathRanking) -> Self
pub fn with_path_ranking(self, ranking: impl PathRanking) -> Self
Add a path ranking strategy.
Path Rankings prioritize paths based on their characteristics.
Ranking priority is determined by the order in which they are added to the stack, the first having the highest priority.
If no ranking strategies are added, ranking will default to
Shortest.